This page is taken from the
[examples/widgets/](https://github.com/google-gemini/genai-processors/blob/main/examples/widgets/)
directory and refers to the code there.

{% include-markdown "../../../examples/widgets/README.md" %}
